pub struct GenericJoinSplit {
pub vpub_old: Amount<NonNegative>,
pub vpub_new: Amount<NonNegative>,
pub anchor: Root,
pub nullifiers: [Nullifier; 2],
pub commitments: [NoteCommitment; 2],
pub ephemeral_key: PublicKey,
pub random_seed: RandomSeed,
pub vmacs: [Mac; 2],
pub zkproof: Option<Vec<u8>>,
pub enc_ciphertexts: [EncryptedNote; 2],
}Expand description
The same as JoinSplit but with a serialized proof, so that the type
isn’t generic anymore.
Fields
vpub_old: Amount<NonNegative>A value that the JoinSplit transfer removes from the transparent value pool.
vpub_new: Amount<NonNegative>A value that the JoinSplit transfer inserts into the transparent value pool.
anchor: RootA root of the Sprout note commitment tree at some block height in the past, or the root produced by a previous JoinSplit transfer in this transaction.
nullifiers: [Nullifier; 2]A nullifier for the input notes.
commitments: [NoteCommitment; 2]A note commitment for this output note.
ephemeral_key: PublicKeyAn X25519 public key.
random_seed: RandomSeedA 256-bit seed that must be chosen independently at random for each JoinSplit description.
vmacs: [Mac; 2]A message authentication tag.
zkproof: Option<Vec<u8>>A ZK JoinSplit proof, either a serialized
Groth16Proof or a Bctv14Proof.
enc_ciphertexts: [EncryptedNote; 2]A ciphertext component for this output note.